import { __awaiter, __decorate } from "tslib";
import { Session } from '@genesislcap/foundation-comms';
/**
 * Implementation for the Local Storage State Persistence interface.
 * @public
 */
export class LocalStorageStatePersistence {
    getColumnState(persistColumnStateKey) {
        return __awaiter(this, void 0, void 0, function* () {
            const localStorageGridOptions = this.session.getLocalStorageItem('gridOptions');
            if (localStorageGridOptions) {
                const allGridOptions = JSON.parse(localStorageGridOptions);
                if (persistColumnStateKey in allGridOptions) {
                    return JSON.parse(allGridOptions[persistColumnStateKey]);
                }
            }
            return [];
        });
    }
    saveColumnState(persistColumnStateKey, columnState) {
        return __awaiter(this, void 0, void 0, function* () {
            const existingOptions = JSON.parse(this.session.getLocalStorageItem('gridOptions') || '{}');
            existingOptions[persistColumnStateKey] = JSON.stringify(columnState);
            this.session.setLocalStorageItem('gridOptions', JSON.stringify(existingOptions));
        });
    }
    getFilterModel(persistFilterModelKey) {
        return __awaiter(this, void 0, void 0, function* () {
            const localStorageGridOptions = this.session.getLocalStorageItem('gridOptions');
            if (localStorageGridOptions) {
                const allGridOptions = JSON.parse(localStorageGridOptions);
                if (persistFilterModelKey in allGridOptions) {
                    return JSON.parse(allGridOptions[persistFilterModelKey]);
                }
            }
            return {};
        });
    }
    saveFilterModel(persistFilterModelKey, filterModel) {
        return __awaiter(this, void 0, void 0, function* () {
            const existingOptions = JSON.parse(this.session.getLocalStorageItem('gridOptions') || '{}');
            existingOptions[persistFilterModelKey] = JSON.stringify(filterModel);
            this.session.setLocalStorageItem('gridOptions', JSON.stringify(existingOptions));
        });
    }
}
__decorate([
    Session
], LocalStorageStatePersistence.prototype, "session", void 0);
